@@ -1,6 +1,6 @@
 dyplot.CalGR <- function(x, ...) {
 
-  if (! any(class(x) %in% "CalGR")) {
+  if (!inherits(x, "CalGR")) {
     stop("Non convenient data for x argument. Must be of class \"CalGR\"")
   }
 
